BodyMetrics class

Constructors

BodyMetrics()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bmiCategory(double bmi) String
Get BMI Category
calculateBMI(UserData user) double
Calculate BMI
calculateBMR(UserData user) double
Calculate Basal Metabolic Rate (BMR) using Mifflin-St Jeor
calculateTDEE(UserData user) double
Calculate Total Daily Energy Expenditure (TDEE)
calorieGoal(UserData user, String goal) double
Suggest calorie intake based on goal: lose, gain, maintain